@@ -68,7 +68,7 @@ def get_script_name_key(job_type):
 def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=False, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
-                         cluster_tags=[], instance_type=None, project_build=None):
+                         cluster_tags=[], instance_type=None, project_build=None, cluster_configuration=None):
     """
     Post a new job to a new cluster.
 
@@ -137,7 +137,8 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
             'pipeline_job_id': pipeline_job_id,
             'job_type': job_type,
             get_script_name_key(job_type): script_name,
-            'project_build': project_build
+            'project_build': project_build,
+            'cluster_configuration': cluster_configuration
     }
 
     if pig_version:
@@ -148,7 +149,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
 
 def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                              parameters=None, notify_on_job_finish=True, pig_version=None, use_spot_instances=False,
-                             job_type=JOB_TYPE_PIG):
+                             job_type=JOB_TYPE_PIG, cluster_configuration=None):
     """
     Post a new job to a new cluster.
 
@@ -191,7 +192,8 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
             'notify_on_job_finish': notify_on_job_finish,
             'use_spot_instances': use_spot_instances,
             'job_type': job_type,
-            get_script_name_key(job_type): script_name
+            get_script_name_key(job_type): script_name,
+            'cluster_configuration': cluster_configuration
     }
 
     if pig_version:
